@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 """KhtEditor a source code editor by Khertan"""
 import khweeteur
+import sys
 
 if __name__ == '__main__':
-    khweeteur.Khweeteur()
\ No newline at end of file
+    sys.exit(khweeteur.Khweeteur().exec_())
